onReady method
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
Implementation
@override
void onReady() {
super.onReady();
autoDispose(
_tasks.listen(
(data) {
if (isProcessing.value != data.isNotEmpty) {
isProcessing.toggle();
}
},
),
);
}