RxQueryPageable<Query, Response> class
- Inheritance
- Implemented types
- Implementers
- Available extensions
Constructors
-
RxQueryPageable({required Query query, required Future<
List< dataSource(Query query, PageableRequest request), bool isAutoStart = true})Response> >
Properties
- canUpdate → bool
-
no setterinherited
- currentStatus → String
-
no setter
-
dataSource
↔ Future<
List< Function(Query query, PageableRequest request)Response> > -
getter/setter pair
- first ↔ Response
-
The first element.
getter/setter pairinherited
- firstOrNull → T?
-
Available on Iterable<
The first element of this iterator, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - firstRebuild ↔ bool
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indexed
→ Iterable<
(int, T)> -
Available on Iterable<
Pairs of elements of the indices and elements of this iterable.T> , provided by the IterableExtensions extensionno setter - isAutoStart ↔ bool
-
getter/setter pairoverride
- isEmpty → bool
-
Whether this collection has no elements.
no setterinherited
- isNotEmpty → bool
-
Whether this collection has at least one element.
no setterinherited
-
iterator
→ Iterator<
Response> -
A new
Iteratorthat allows iterating the elements of thisIterable.no setterinherited - last ↔ Response
-
The last element.
getter/setter pairinherited
- lastOrNull → T?
-
Available on Iterable<
The last element of this iterable, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - length ↔ int
-
The number of objects in this list.
getter/setter pairinherited
-
nonNulls
→ Iterable<
T> -
Available on Iterable<
The non-T?> , provided by the NullableIterableExtensions extensionnullelements of this iterable.no setter - query ↔ Query
-
getter/setter pair
-
reversed
→ Iterable<
Response> -
An Iterable of the objects in this list in reverse order.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sentToStream ↔ bool
-
getter/setter pairinherited
- single → Response
-
Checks that this iterable has only one element, and returns that element.
no setterinherited
- singleOrNull → T?
-
Available on Iterable<
The single element of this iterator, orT> , provided by the IterableExtensions extensionnull.no setter -
stream
→ Stream<
List< Response> > -
no setterinherited
- string → String
-
Same as
toString()but using a getter.no setterinherited -
subject
↔ GetStream<
List< Response> > -
getter/setter pairinherited
-
toJS
→ JSArray<
T> -
Available on List<
Converts this List to a JSArray by either casting, unwrapping, or cloning the List.T> , provided by the ListToJSArray extensionno setter -
toJSProxyOrRef
→ JSArray<
T> -
Available on List<
Converts this List to a JSArray by either casting, unwrapping, or proxying the List.T> , provided by the ListToJSArray extensionno setter -
value
↔ List<
Response> -
Returns the current value
getter/setter pairinherited
-
wait
→ Future<
List< T> > -
Available on Iterable<
Waits for futures in parallel.Future< , provided by the FutureIterable extensionT> >no setter
Methods
-
add(
Response element) → void -
Adds
valueto the end of this list, extending the length by one.inherited -
addAll(
Iterable< Response> iterable) → void -
Appends all objects of
iterableto the end of this list.inherited -
addListener(
GetStream< List< rxGetx) → voidResponse> > -
This is an internal method.
Subscribe to changes on the inner stream.
inherited
-
any(
bool test(Response element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
asMap(
) → Map< int, Response> -
An unmodifiable Map view of this list.
inherited
-
asNameMap(
) → Map< String, T> -
Available on Iterable<
Creates a map from the names of enum values to the values.T> , provided by the EnumByName extension -
bindStream(
Stream< List< stream) → voidResponse> > -
Binds an existing
Stream<T>to thisRx<T>to keep the values in sync. You can bind multiple sources to update the value. Closing the subscription will happen automatically when the observer Widget (GetXorObx) gets unmounted from the Widget tree.inherited -
byName(
String name) → T -
Available on Iterable<
Finds the enum value in this list with nameT> , provided by the EnumByName extensionname. -
call(
[List< Response> ? v]) → List<Response> -
updates the value to
nulland adds it to the Stream. Even with null-safety coming, is still an important feature to support, ascall()doesn't acceptnullvalues. For instance,InputDecoration.errorTexthas to be null to not show the "error state".inherited -
cast<
R> () → List< R> -
Returns a view of this list as a list of
Rinstances.inherited -
clear(
) → void -
Removes all objects from this list; the length of the list becomes zero.
inherited
-
close(
) → void -
Closes the subscriptions for this Rx, releasing the resources.
inherited
-
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.inherited -
elementAt(
int index) → Response -
Returns the
indexth element.inherited -
elementAtOrNull(
int index) → T? -
Available on Iterable<
The element at positionT> , provided by the IterableExtensions extensionindexof this iterable, ornull. -
every(
bool test(Response element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
expand<
T> (Iterable< T> f(Response element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
fillRange(
int start, int end, [Response? fill]) → void -
Overwrites a range of elements with
fillValue.inherited -
firstWhere(
bool test(Response element), {Response orElse()?}) → Response -
The first element that satisfies the given predicate
test.inherited -
fold<
T> (T initialValue, T combine(T previousValue, Response element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
followedBy(
Iterable< Response> other) → Iterable<Response> -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void action(Response element)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
getRange(
int start, int end) → Iterable< Response> -
Creates an Iterable that iterates over a range of elements.
inherited
-
indexOf(
Object? element, [int start = 0]) → int -
The first index of
elementin this list.inherited -
indexWhere(
bool test(Response element), [int start = 0]) → int -
The first index in the list that satisfies the provided
test.inherited -
insert(
int index, Response element) → void -
Inserts
elementat positionindexin this list.inherited -
insertAll(
int index, Iterable< Response> iterable) → void -
Inserts all objects of
iterableat positionindexin this list.inherited -
item(
int index) → Response -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
lastIndexOf(
Object? element, [int? start]) → int -
The last index of
elementin this list.inherited -
lastIndexWhere(
bool test(Response element), [int? start]) → int -
The last index in the list that satisfies the provided
test.inherited -
lastWhere(
bool test(Response element), {Response orElse()?}) → Response -
The last element that satisfies the given predicate
test.inherited -
listen(
void onData(List< Response> ), {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription<List< Response> > -
inherited
-
listenAndPump(
void onData(List< Response> event), {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription<List< Response> > -
Returns a StreamSubscription similar to
listen, but with the added benefit that it primes the stream with the currentvalue, rather than waiting for the nextvalue. This should not be called inonInitor anywhere else during the build process.inherited -
map<
T> (T f(Response element)) → Iterable< T> -
The current elements of this iterable modified by
toElement.inherited -
next(
) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reduce(
Response combine(Response previousValue, Response element)) → Response -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
refresh(
) → void -
Makes a direct update of
valueadding it to the Stream useful when you make use of Rx for custom Types to referesh your UI.inherited -
reloadDataSource(
{Query? updatedQuery}) → Future -
override
-
remove(
Object? element) → bool -
Removes the first occurrence of
valuefrom this list.inherited -
removeAt(
int index) → Response -
Removes the object at position
indexfrom this list.inherited -
removeLast(
) → Response -
Removes and returns the last object in this list.
inherited
-
removeRange(
int start, int end) → void -
Removes a range of elements from the list.
inherited
-
removeWhere(
bool test(Response element)) → void -
Removes all objects from this list that satisfy
test.inherited -
replaceRange(
int start, int end, Iterable< Response> newContents) → void -
Replaces a range of elements with the elements of
replacements.inherited -
retainWhere(
bool test(Response element)) → void -
Removes all objects from this list that fail to satisfy
test.inherited -
setAll(
int index, Iterable< Response> iterable) → void -
Overwrites elements with the objects of
iterable.inherited -
setRange(
int start, int end, Iterable< Response> iterable, [int skipCount = 0]) → void -
Writes some elements of
iterableinto a range of this list.inherited -
shuffle(
[Random? random]) → void -
Shuffles the elements of this list randomly.
inherited
-
singleWhere(
bool test(Response element), {Response orElse()?}) → Response -
The single element that satisfies
test.inherited -
skip(
int count) → Iterable< Response> -
Creates an Iterable that provides all but the first
countelements.inherited -
skipWhile(
bool test(Response element)) → Iterable< Response> -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
sort(
[int compare(Response a, Response b)?]) → void -
Sorts this list according to the order specified by the
comparefunction.inherited -
sublist(
int start, [int? end]) → List< Response> -
Returns a new list containing the elements between
startandend.inherited -
take(
int count) → Iterable< Response> -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeWhile(
bool test(Response element)) → Iterable< Response> -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
toJson(
) → dynamic -
Returns the json representation of
value.inherited -
toList(
{bool growable = true}) → List< Response> -
Creates a List containing the elements of this Iterable.
inherited
-
toPageableList(
{required Widget builder(Response item), bool reverse = false, bool shrinkWrap = false, Widget? header, Widget? separator, Widget? empty, EdgeInsetsGeometry? padding, Axis scrollDirection = Axis.vertical, VoidCallback? next}) → RxPageableList< Request, Response> -
Available on RxQueryPageable<
Request, Response> , provided by the RxPageableX extension -
toSet(
) → Set< Response> -
Creates a Set containing the same elements as this iterable.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toWidget(
Widget builder(RxQueryPageable< Request, Response> rx)) → ObxValue<RxQueryPageable< Request, Response> > -
Available on RxQueryPageable<
Request, Response> , provided by the GetExtensionX extension -
where(
bool test(Response)) → Iterable< Response> -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereType<
T> () → Iterable< T> -
Creates a new lazy Iterable with all elements that have type
T.inherited
Operators
-
operator +(
Iterable< Response> val) → RxList<Response> -
Special override to push() element(s) in a reactive way
inside the List,
inherited
-
operator ==(
Object o) → bool -
This equality override works for _RxImpl instances and the internal
values.
inherited
-
operator [](
int index) → Response -
The object at the given
indexin the list.inherited -
operator []=(
int index, Response val) → void -
Sets the value at the given
indexin the list tovalue.inherited
Static Properties
- defaultFirstPage ↔ int
-
getter/setter pair
- pageSize ↔ int
-
getter/setter pair